package nagios

import (
	"github.com/stretchr/testify/assert"
	"testing"
)

func TestOverall_AddOK(t *testing.T) {
	overall := Overall{}
	overall.Add(0, "test ok")

	assert.Equal(t, 1, overall.OKs)
	assert.ElementsMatch(t, overall.Outputs, []string{"[OK] test ok"})
}

func TestOverall_AddWarning(t *testing.T) {
	overall := Overall{}
	overall.Add(1, "test warning")

	assert.Equal(t, 1, overall.Warnings)
	assert.ElementsMatch(t, overall.Outputs, []string{"[WARNING] test warning"})
}

func TestOverall_AddCritical(t *testing.T) {
	overall := Overall{}
	overall.Add(2, "test critical")

	assert.Equal(t, 1, overall.Criticals)
	assert.ElementsMatch(t, overall.Outputs, []string{"[CRITICAL] test critical"})
}

func TestOverall_AddUnknown(t *testing.T) {
	overall := Overall{}
	overall.Add(3, "test unknown")

	assert.Equal(t, 1, overall.Unknowns)
	assert.ElementsMatch(t, overall.Outputs, []string{"[UNKNOWN] test unknown"})
}

func TestOverall_GetStatus_GetSummary(t *testing.T) {
	var overall Overall

	overall = Overall{}
	assert.Equal(t, 3, overall.GetStatus())
	assert.Equal(t, "No status information", overall.GetSummary())

	overall = Overall{OKs: 1}
	assert.Equal(t, 0, overall.GetStatus())
	assert.Equal(t, "states: ok=1", overall.GetSummary())

	overall = Overall{Criticals: 2, OKs: 1, Warnings: 2, Unknowns: 1}
	assert.Equal(t, 2, overall.GetStatus())
	assert.Equal(t, "states: critical=2 unknown=1 warning=2 ok=1", overall.GetSummary())

	overall = Overall{Unknowns: 2, OKs: 1, Warnings: 2}
	assert.Equal(t, 3, overall.GetStatus())
	assert.Equal(t, "states: unknown=2 warning=2 ok=1", overall.GetSummary())

	overall = Overall{OKs: 1, Warnings: 2}
	assert.Equal(t, 1, overall.GetStatus())
	assert.Equal(t, "states: warning=2 ok=1", overall.GetSummary())
}

func TestOverall_GetOutput(t *testing.T) {
	var overall Overall

	overall = Overall{}
	overall.Add(0, "First OK")
	overall.Add(0, "Second OK")

	assert.Equal(t, "states: ok=2\n[OK] First OK\n[OK] Second OK\n", overall.GetOutput())

	overall = Overall{}
	overall.Add(0, "State OK")
	// TODO: compress when only one state
	assert.Equal(t, "states: ok=1\n[OK] State OK\n", overall.GetOutput())

	overall = Overall{}
	overall.Add(0, "First OK")
	overall.Add(2, "Second Critical")
	overall.Summary = "Custom Summary"
	assert.Equal(t, "Custom Summary\n[OK] First OK\n[CRITICAL] Second Critical\n", overall.GetOutput())

}
